# Full API

::: asdex.jacobian
::: asdex.value_and_jacobian
::: asdex.hessian
::: asdex.value_and_hessian

---

::: asdex.jacobian_from_coloring
::: asdex.value_and_jacobian_from_coloring
::: asdex.hessian_from_coloring
::: asdex.value_and_hessian_from_coloring

---

::: asdex.jacobian_coloring
::: asdex.hessian_coloring

---

::: asdex.jacobian_coloring_from_sparsity
::: asdex.hessian_coloring_from_sparsity

---

::: asdex.jacobian_sparsity
::: asdex.hessian_sparsity

---

::: asdex.SparsityPattern
::: asdex.ColoredPattern

---

::: asdex.JacobianMode
::: asdex.HessianMode
